<?php

/**
 * @file
 * Settings functions
 *
 * @author Tim Leytens
 */

/**
 * Settings form for the login credentials
 */
function campaign_monitor_login_settings() {

  drupal_get_messages();
  $connected = _campaign_monitor_client_connected();

  $form = array();

  if ($connected) {

    drupal_set_message(t('You are now connected to Campaign monitor'));

    $form['campaign_monitor_revoke_access'] = array(
      '#type' => 'submit',
      '#value' => t('Revoke access'),
    );
    $form['#submit'][] = '_campaign_monitor_revoke_access';
    return $form;

  }
  else {

    drupal_set_message(t('You are not connected to Campaign monitor'), 'warning');

    $form['campaign_monitor_api_key'] = array(
      '#type' => 'textfield',
      '#title' => t('API Key'),
      '#description' => t('Your Campaign Monitor API Key. See Campaign Monitor\'s <a href="http://www.campaignmonitor.com/api/required/">documentation</a> for more info.'),
      '#default_value' => variable_get('campaign_monitor_api_key', ''),
      '#required' => TRUE,
    );
    $form['campaign_monitor_client_id'] = array(
      '#type' => 'textfield',
      '#title' => t('Client ID'),
      '#description' => t('Your Campaign Monitor Client ID. See Campaign Monitor\'s <a href="http://www.campaignmonitor.com/api/required/">documentation</a> for more info.'),
      '#default_value' => variable_get('campaign_monitor_client_id', ''),
      '#required' => TRUE,
    );
    $form['campaign_monitor_api'] = array(
      '#type' => 'textfield',
      '#title' => t('API directory'),
      '#description' => t('Location of the Campaign monitor API e.g. "sites/all/libraries/campaignmonitor-createsend-php"'),
      '#default_value' => variable_get('campaign_monitor_api', 'sites/all/libraries/campaignmonitor-createsend-php'),
      '#required' => TRUE,
    );
    return system_settings_form($form);

  }
}

/**
 * Validate handler for the login settings form
 */
function campaign_monitor_login_settings_validate($form, &$form_state) {
  if (isset($form_state['values']['campaign_monitor_api'])) {
    if (!_campaign_monitor_api_path_exists($form_state['values']['campaign_monitor_api'])) {
      form_set_error('campaign_monitor_api', t('Location for the Campaign monitor API is not valid'));
    }
  }
}

/**
 * Settings form for the lists
 */
function campaign_monitor_lists_settings() {

  $connected = _campaign_monitor_client_connected();

  if ($connected) {

    $lists = _campaign_monitor_client_lists();
    $form = array();

    if (is_array($lists)) {
      $values = variable_get('campaign_monitor_lists', array());
      foreach ($lists as $key => $value) {

        $exists = array_key_exists($value->ListID, $values) ? TRUE : FALSE;

        $form['#rows'][$value->ListID] = $exists ? $values[$value->ListID]['weight'] : 0;
        $form['rows'][$value->ListID]['name-' . $value->ListID] = array(
          '#type' => 'markup',
          '#value' => t($value->Name),
        );
        $form['rows'][$value->ListID]['weight-' . $value->ListID] = array(
          '#type' => 'weight',
          '#size' => 5,
          '#default_value' => $exists ? $values[$value->ListID]['weight'] : 0,
          '#attributes' => array('class' => 'weight'),
        );
        $form['rows'][$value->ListID]['block-' . $value->ListID] = array(
          '#type' => 'checkbox',
          '#title' => t('Provide subscribe block'),
          '#default_value' => $exists ? $values[$value->ListID]['block'] : 0,
        );
        $form['rows'][$value->ListID]['include-' . $value->ListID] = array(
          '#type' => 'checkbox',
          '#title' => t('Checkbox at profile and registration page'),
          '#default_value' => $exists ? $values[$value->ListID]['include'] : 0,
        );
        $form['rows'][$value->ListID]['default-' . $value->ListID] = array(
          '#type' => 'checkbox',
          '#title' => t('Checkbox checked by default'),
          '#default_value' => $exists ? $values[$value->ListID]['default'] : 0,
        );
        $form['rows'][$value->ListID]['title-' . $value->ListID] = array(
          '#type' => 'textfield',
          '#title' => t('Title'),
          '#default_value' => $exists ? $values[$value->ListID]['title'] : '',
        );
        $form['rows'][$value->ListID]['description-' . $value->ListID] = array(
          '#type' => 'textarea',
          '#title' => t('Description'),
          '#default_value' => $exists ? $values[$value->ListID]['description'] : '',
        );
        $form['rows'][$value->ListID]['listname-' . $value->ListID] = array(
          '#type' => 'hidden',
          '#default_value' => $value->Name,
        );
      }
      $form['submit'] = array(
        '#type' => 'submit',
        '#value' => t('Save'),
      );
      $form['reset'] = array(
        '#type' => 'submit',
        '#value' => t('Reset all values'),
      );
    }
    return $form;
  }
  else {
    drupal_goto('admin/settings/campaign_monitor');
  }
}

/**
 * submit handler for lists settings form
 */
function campaign_monitor_lists_settings_submit($form, &$form_state) {
  if ($form_state['clicked_button']['#id'] == 'edit-submit') {
    $settings = array();
    foreach ($form['#rows'] as $key => $value) {
      $settings[$key] = array(
        'block' => $form_state['values']['block-' . $key],
        'include' => $form_state['values']['include-' . $key],
        'title' => $form_state['values']['title-' . $key],
        'description' => $form_state['values']['description-' . $key],
        'default' => $form_state['values']['default-' . $key],
        'weight' => $form_state['values']['weight-' . $key],
        'name' => $form_state['values']['listname-' . $key],
      );
    }
    variable_set('campaign_monitor_lists', $settings);
  }
  if ($form_state['clicked_button']['#id'] == 'edit-reset') {
    variable_del('campaign_monitor_lists');
  }
  module_invoke('menu', 'rebuild');
}

/**
 * Form to add a list to campaign monitor
 */
function campaign_monitor_add_list() {

  $connected = _campaign_monitor_client_connected();

  if ($connected) {

    $form['#redirect'] = 'admin/settings/campaign_monitor/lists';
    $form['name'] = array(
      '#type' => 'textfield',
      '#title' => t('List name'),
      '#description' => t('Give a name for the new Campaign monitor list'),
      '#required' => TRUE,
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
    );
    return $form;

  }
  else {
    drupal_goto('admin/settings/campaign_monitor');
  }
}

/**
 * Submit handler for the Form to add a list to campaign monitor
 */
function campaign_monitor_add_list_submit($form, &$form_state) {

  $login = _campaign_monitor_get_login();

  $wrap = new CS_REST_Lists(NULL, $login['api_key']);

  $result = $wrap->create($login['client_id'], array(
    'Title' => check_plain($form_state['values']['name']),
    'ConfirmedOptIn' => FALSE,
  ));

  if (!$result->was_successful()) {
    drupal_set_message(t('List could not be created'), 'error');
  }

}

/**
 * Form to sync campaign monitor
 */
function campaign_monitor_sync_form() {

  $connected = _campaign_monitor_client_connected();

  if ($connected) {

    $form['markup'] = array(
      '#type' => 'markup',
      '#prefix' => '<p>',
      '#value' => t('Manually synchronize your site with Campaign monitor'),
      '#suffix' => '</p>',
    );
    $form['submit'] = array(
      '#type' => 'submit',
      '#value' => t('Synchronize'),
    );
    return $form;

  }
  else {
    drupal_goto('admin/settings/campaign_monitor');
  }
}

/**
 * Submit handler to sync campaign monitor
 */
function campaign_monitor_sync_form_submit($form, &$form_state) {
  if (campaign_monitor_sync()) {
    variable_set('campaign_monitor_last_sync', time());
    drupal_set_message(t('Synchronization complete'));
  }
}

/**
 * General settings form
 */
function campaign_monitor_general_settings() {

  $settings = variable_get('campaign_monitor_settings', array());

  $form['campaign_monitor_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('General settings'),
  );
  $form['campaign_monitor_settings']['unsubscribe_deleted'] = array(
    '#type' => 'checkbox',
    '#title' => t('Unsubscribe on user delete'),
    '#description' => t('Unsubscribe user when account is deleted'),
    '#default_value' => array_key_exists('unsubscribe_deleted', $settings) ? $settings['unsubscribe_deleted'] : 0,
  );
  $form['campaign_monitor_settings']['subscribed_block'] = array(
    '#type' => 'select',
    '#title' => t('Block behavior when subscribed'),
    '#description' => t('When a user subscribes, should we hide the subscribe block or change to an unsubscribe block'),
    '#options' => array(
      'hide' => 'Hide block',
      'unsubscribe' => 'Unsubscribe block',
    ),
    '#default_value' => array_key_exists('subscribed_block', $settings) ? $settings['subscribed_block'] : 'hide',
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Submit handler for the general settings form
 */
function campaign_monitor_general_settings_submit($form, &$form_state) {
  $settings = array(
    'unsubscribe_deleted' => $form_state['values']['unsubscribe_deleted'],
    'subscribed_block' => $form_state['values']['subscribed_block'],
  );
  variable_set('campaign_monitor_settings', $settings);
}